@@ -4,8 +4,10 @@ use std::{
     fmt::{self, Debug, Formatter},
 };
 
+#[cfg(feature = "websocket")]
 use hyper::upgrade::OnUpgrade;
 use once_cell::sync::Lazy;
+#[cfg(feature = "websocket")]
 use parking_lot::Mutex;
 
 use crate::{
@@ -23,8 +25,8 @@ pub(crate) struct RequestState {
     pub(crate) remote_addr: RemoteAddr,
     pub(crate) original_uri: Uri,
     pub(crate) match_params: PathParams,
-    pub(crate) cookie_jar: CookieJar,
-    #[allow(dead_code)]
+    pub(crate) cookie_jar: Option<CookieJar>,
+    #[cfg(feature = "websocket")]
     pub(crate) on_upgrade: Mutex<Option<OnUpgrade>>,
 }
 
@@ -37,6 +39,7 @@ impl Default for RequestState {
             original_uri: Default::default(),
             match_params: Default::default(),
             cookie_jar: Default::default(),
+            #[cfg(feature = "websocket")]
             on_upgrade: Default::default(),
         }
     }
@@ -67,9 +70,9 @@ impl Debug for Request {
 
 impl From<(http::Request<hyper::Body>, RemoteAddr)> for Request {
     fn from((req, remote_addr): (http::Request<hyper::Body>, RemoteAddr)) -> Self {
+        #[allow(unused_mut)]
         let (mut parts, body) = req.into_parts();
-
-        let cookie_jar = extract_cookie_jar(&parts.headers);
+        #[cfg(feature = "websocket")]
         let on_upgrade = Mutex::new(parts.extensions.remove::<OnUpgrade>());
 
         Self {
@@ -83,7 +86,8 @@ impl From<(http::Request<hyper::Body>, RemoteAddr)> for Request {
                 remote_addr,
                 original_uri: parts.uri,
                 match_params: Default::default(),
-                cookie_jar,
+                cookie_jar: None,
+                #[cfg(feature = "websocket")]
                 on_upgrade,
             },
         }
@@ -201,7 +205,12 @@ impl Request {
     /// Returns a reference to the [`CookieJar`]
     #[inline]
     pub fn cookie(&self) -> &CookieJar {
-        &self.state.cookie_jar
+        match &self.state.cookie_jar {
+            Some(cookie_jar) => cookie_jar,
+            None => panic!(
+                "To use the `CookieJar` extractor, the `CookieJarManager` middleware is required."
+            ),
+        }
     }
 
     /// Sets the body for this request.
@@ -301,7 +310,6 @@ impl RequestBuilder {
     /// Consumes this builder, using the provided body to return a constructed
     /// [Request].
     pub fn body(self, body: impl Into<Body>) -> Request {
-        let cookie_jar = extract_cookie_jar(&self.headers);
         Request {
             method: self.method,
             uri: self.uri,
@@ -309,10 +317,7 @@ impl RequestBuilder {
             headers: self.headers,
             extensions: self.extensions,
             body: body.into(),
-            state: RequestState {
-                cookie_jar,
-                ..Default::default()
-            },
+            state: Default::default(),
         }
     }
 
@@ -322,30 +327,3 @@ impl RequestBuilder {
         self.body(Body::empty())
     }
 }
-
-fn extract_cookie_jar(headers: &HeaderMap) -> CookieJar {
-    headers
-        .get(header::COOKIE)
-        .and_then(|value| std::str::from_utf8(value.as_bytes()).ok())
-        .and_then(|value| value.parse().ok())
-        .unwrap_or_default()
-}
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-    use crate::web::Cookie;
-
-    #[test]
-    fn parse_cookie_jar_in_builder() {
-        let req = Request::builder()
-            .header(header::COOKIE, Cookie::new("a", "10").to_string())
-            .finish();
-        assert_eq!(
-            req.cookie()
-                .get("a")
-                .map(|cookie| cookie.value().to_string()),
-            Some("10".to_string())
-        );
-    }
-}
