@@ -229,7 +229,7 @@ impl<T> Node<T> {
 
         if let Some(pos) = self.find_static_child(path[0]) {
             let child = &self.children[pos];
-            if path == &child.name {
+            if path == child.name {
                 if let Some(data) = child.matches(&[], params) {
                     return Some(data);
                 }
